/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.bluez.Media1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BLUEZMEDIA1_H
#define BLUEZMEDIA1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.bluez.Media1
 */
class OrgBluezMedia1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.bluez.Media1"; }

public:
    OrgBluezMedia1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgBluezMedia1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> RegisterEndpoint(const QDBusObjectPath &endpoint, const QVariantMap &properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(endpoint) << QVariant::fromValue(properties);
        return asyncCallWithArgumentList(QStringLiteral("RegisterEndpoint"), argumentList);
    }

    inline QDBusPendingReply<> UnregisterEndpoint(const QDBusObjectPath &endpoint)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(endpoint);
        return asyncCallWithArgumentList(QStringLiteral("UnregisterEndpoint"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace bluez {
    using Media1 = ::OrgBluezMedia1Interface;
  }
}

#endif
